TraceState class abstract

Representation of the state of a trace.

Implementers

Constructors

TraceState()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this TraceState is empty.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
The number of key/value pairs contained in this TraceState.
no setter

Methods

get(String key) → String?
Retrieve a value from the TraceState for a given key.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String key, String value) → void
Adds a key value pair to the TraceState.
remove(String key) → void
Removes a key value pair from the TraceState.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited